@@ -11,8 +11,8 @@ def callback():
     """
 
 
-@app.command(upper: bool = typer.Option(False, help="Is uppercase."),
-def common():         
+@app.command()
+def common(upper: bool = typer.Option(False, help="Say hi uppercase.")):
     if upper:
         text = "HI MATE!" 
     else:
